# atl-hello-world-component # 

This is a simple example of atl-django-component.

## How to use it? ##

View [atl-hello-world-component documentation](https://bitbucket.org/atlantesoftware/atl-hello-world-component)